PatternType enum

Predefined regex patterns for common validation types.

Inheritance
Available extensions

Values

email → const PatternType

Email address pattern

phone → const PatternType

Phone number pattern

number → const PatternType

Numeric only pattern

strongPassword → const PatternType

Strong password pattern

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(String input) bool

Available on PatternType, provided by the PatternTypeExtension extension

Validates input string against the pattern type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PatternType>
A constant List of the values in this enum, in order of their declaration.