SahihLanguage enum

Supported languages for validation error messages.

Inheritance
Available extensions

Values

en → const SahihLanguage

English (Default)

ar → const SahihLanguage

Arabic

es → const SahihLanguage

Spanish

fr → const SahihLanguage

French

de → const SahihLanguage

German

zh → const SahihLanguage

Chinese

ja → const SahihLanguage

Japanese

pt → const SahihLanguage

Portuguese

hi → const SahihLanguage

Hindi

ru → const SahihLanguage

Russian

tr → const SahihLanguage

Turkish

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SahihLanguage>
A constant List of the values in this enum, in order of their declaration.